@@ -3,8 +3,9 @@
 # Picard, the next-generation MusicBrainz tagger
 #
 # Copyright (C) 2017 Sambhav Kothari
-# Copyright (C) 2018-2020 Philipp Wolfer
+# Copyright (C) 2018-2020, 2023 Philipp Wolfer
 # Copyright (C) 2020 Ray Bouchard
+# Copyright (C) 2020-2021 Laurent Monin
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,6 +21,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
+
 """
 The idea here is to bring the data returned by the AcoustID service into the
 same format as the JSON result from the MB web service. Below methods help us
@@ -140,3 +142,7 @@ def parse_recording(recording):
         recording_mb['sources'] = recording['sources']
 
     return recording_mb
+
+
+def recording_has_metadata(recording):
+    return 'id' in recording and recording.get('title') is not None
